@@ -1,10 +1,11 @@
-
 # import __main__ as main
 # def is_interactive():
 #     return not hasattr(main, '__file__')
-from .lazy_modules import LazyObject
+import inspect
+import json
 import os
 import os.path as osp
+import pickle
 import time
 from collections import defaultdict
 from concurrent.futures import ThreadPoolExecutor
@@ -13,21 +14,24 @@ from functools import partial, wraps
 from glob import glob
 from multiprocessing import Pool
 
+import xxhash
 from fastcore.all import *
 from fastcore.parallel import threaded
 from fastcore.script import *
 from fastcore.script import Param, call_parse
 from loguru import logger
-
-import inspect
-import json
 from PIL import Image
+# from pycocotools.coco import COCO
 from tqdm import tqdm
-from pycocotools.coco import COCO
+# from .lazy_modules import LazyModule
+from lazy_module.core import LazyModule
 
-
-mmcv = LazyObject('mmcv')
-np = LazyObject('numpy')
-ipdb = LazyObject('ipdb')
-cv2 = LazyObject('cv2')
-plt = LazyObject('plt', 'import matplotlib.pyplot as plt')
\ No newline at end of file
+mmcv = LazyModule('mmcv')
+np = LazyModule('numpy')
+cv2 = LazyModule('cv2')
+matplotlib = LazyModule('matplotlib')
+plt = LazyModule('plt', 'import matplotlib.pyplot as plt')
+coco = LazyModule('coco', 'from pycocotools import coco')
+ipdb = LazyModule('ipdb')
+pd = LazyModule('pandas')
+#import ipdb, cv2, matplotlib.pyplot as plt, mmcv, numpy as np, matplotlib
